@@ -2,5 +2,6 @@ from ._version import __version__
 from .builder import FmuBuilder
 from .enums import Fmi3Causality, Fmi3Initial, Fmi3Variability
 from .fmi3slave import Fmi3Slave
-from .variables import Boolean, Integer, UInt64, Real, String, Dimension
+from .variables import Boolean, Enumeration, Int32, Int64, UInt64, Float64, String, Dimension
 from .default_experiment import DefaultExperiment
+from .type_definitions import TypeDefinitions, Item, EnumerationType
