@@ -11,9 +11,10 @@ from xml.etree.ElementTree import Element, SubElement
 
 from .logmsg import LogMsg
 from .default_experiment import DefaultExperiment
+from .type_definitions import TypeDefinitions
 from ._version import __version__ as VERSION
 from .enums import Fmi3Type, Fmi3Status, Fmi3Causality, Fmi3Initial, Fmi3Variability
-from .variables import Boolean, Integer, UInt64, Real, ModelVariable, String
+from .variables import Boolean, Enumeration, Int32, Int64, UInt64, Float64, ModelVariable, String
 
 ModelOptions = namedtuple("ModelOptions", ["name", "value", "cli"])
 
@@ -53,6 +54,7 @@ class Fmi3Slave(ABC):
         self.modelName: Optional[str] = self.__class__.__name__
         self.description: Optional[str] = None
         self.default_experiment: Optional[DefaultExperiment] = None
+        self.type_definitions: Optional[TypeDefinitions] = None
 
     def to_xml(self, model_options: Dict[str, str] = dict()) -> Element:
         """Build the XML representation of the model.
@@ -97,6 +99,9 @@ class Fmi3Slave(ABC):
 
         SubElement(root, "CoSimulation", attrib=options)
 
+        if self.type_definitions is not None:
+            root.append(self.type_definitions.to_xml())
+
         if len(self.log_categories) > 0:
             categories = SubElement(root, "LogCategories")
             for category, description in self.log_categories.items():
@@ -118,7 +123,7 @@ class Fmi3Slave(ABC):
             if self.default_experiment.tolerance is not None:
                 attrib["tolerance"] = str(self.default_experiment.tolerance)
             SubElement(root, "DefaultExperiment", attrib)
-
+            
         variables = SubElement(root, "ModelVariables")
         for v in self.vars.values():
             if ModelVariable.requires_start(v):
@@ -131,7 +136,7 @@ class Fmi3Slave(ABC):
         )
 
         continuous_state_derivatives = list(
-            filter(lambda v: v.variability == Fmi3Variability.continuous and (isinstance(v, Real) and v.derivative is not None), self.vars.values())
+            filter(lambda v: v.variability == Fmi3Variability.continuous and (isinstance(v, Float64) and v.derivative is not None), self.vars.values())
         )
 
         allowed_variability = [None, Fmi3Initial.approx, Fmi3Initial.calculated]
@@ -157,21 +162,20 @@ class Fmi3Slave(ABC):
 
     def __apply_start_value(self, var: ModelVariable):
         vrs = [var.value_reference]
-
-        if isinstance(var, Integer):
-            refs = self.get_integer(vrs)
+        if isinstance(var, Int32):
+            refs = self.get_int32(vrs)
+        elif isinstance(var, (Enumeration, Int64)):
+            refs = self.get_int64(vrs)
         elif isinstance(var, UInt64):
             refs = [val.value for val in self.get_uint64(vrs)]
-            print(refs)
-        elif isinstance(var, Real):
-            refs = self.get_real(vrs)
+        elif isinstance(var, Float64):
+            refs = self.get_float64(vrs)
         elif isinstance(var, Boolean):
             refs = self.get_boolean(vrs)
         elif isinstance(var, String):
             refs = self.get_string(vrs)
         else:
-            raise Exception(f"Unsupported type!")
-
+            raise Exception(f"Unsupported type {type(var)}!")
         var.start = refs if len(getattr(var, "dimensions", [])) > 0 else refs[0]
 
     def register_variable(self, var: ModelVariable, nested: bool = True):
@@ -219,17 +223,29 @@ class Fmi3Slave(ABC):
     def terminate(self):
         pass
 
-    def get_integer(self, vrs: List[int]) -> List[int]:
+    def get_int32(self, vrs: List[int]) -> List[int]:
         refs = list()
         for vr in vrs:
             var = self.vars[vr]
-            if isinstance(var, Integer):
+            if isinstance(var, Int32):
                 refs.append(int(var.getter()))
             else:
                 raise TypeError(
                     f"Variable with valueReference={vr} is not of type Integer!"
                 )
         return refs
+    
+    def get_int64(self, vrs: List[int]) -> List[int]:
+        refs = list()
+        for vr in vrs:
+            var = self.vars[vr]
+            if isinstance(var, (Enumeration, Int64)):
+                refs.append(int(var.getter()))
+            else:
+                raise TypeError(
+                    f"Variable with valueReference={vr} is not of type Int64!"
+                )
+        return refs
 
     def get_uint64(self, vrs: List[int]) -> List[ctypes.c_uint64]:
         refs = list()
@@ -244,11 +260,11 @@ class Fmi3Slave(ABC):
                 )
         return refs
 
-    def get_real(self, vrs: List[int]) -> List[float]:
+    def get_float64(self, vrs: List[int]) -> List[float]:
         refs = list()
         for vr in vrs:
             var = self.vars[vr]
-            if isinstance(var, Real):
+            if isinstance(var, Float64):
                 if len(var.dimensions) == 0:
                     refs.append(float(var.getter()))
                 else:
@@ -283,10 +299,20 @@ class Fmi3Slave(ABC):
                 )
         return refs
 
-    def set_integer(self, vrs: List[int], values: List[int]):
+    def set_int32(self, vrs: List[int], values: List[int]):
         for vr, value in zip(vrs, values):
             var = self.vars[vr]
-            if isinstance(var, Integer):
+            if isinstance(var, Int32):
+                var.setter(value)
+            else:
+                raise TypeError(
+                    f"Variable with valueReference={vr} is not of type Integer!"
+                )
+                
+    def set_int64(self, vrs: List[int], values: List[int]):
+        for vr, value in zip(vrs, values):
+            var = self.vars[vr]
+            if isinstance(var, (Enumeration, Int64)):
                 var.setter(value)
             else:
                 raise TypeError(
@@ -303,11 +329,11 @@ class Fmi3Slave(ABC):
                     f"Variable with valueReference={vr} is not of type UInt64!"
                 )
 
-    def set_real(self, vrs: List[int], values: List[float]):
+    def set_float64(self, vrs: List[int], values: List[float]):
         offset = 0
         for vr in vrs:
             var = self.vars[vr]
-            if isinstance(var, Real):
+            if isinstance(var, Float64):
                 size = var.size(self.vars)
                 if size > 1:
                     var.setter(values[offset:offset+size])
